@@ -67,7 +67,7 @@ class TT_API:
     def send_text(self, content: str, to_users=[]):
         if to_users:
             self._to_users = to_users
-        _check_legal(self._to_users, self.check_legal)
+        _check_legal(self._to_users, self._check_legal)
         api_path = '/s/api/message/notification/send'
         payload = {
             'appid': self._appid,
